==============
Administration
==============

The Chat plugin allows field users to chat with each other, they can also chat with
external systems.

-   SOS / Emergency Message can be sent from PowerOn to resource.
    Message captures screen & gives audible warning.

-   SOS messages can be sent to multiple or all logged on mobile devices.

-   SOS / Emergency Message can be sent from mobile device to PowerOn.
    Message raises an alarm in PowerOn.

-   Alarm is raised if the message isn’t delivered or resource doesn’t respond
    in a given time.

-   Instant messages of text can be sent to PowerOn from the mobile device,
    from either stock phrases or freehand.

Message Flow
------------

.. image:: flow_diagram.png